@@ -13,7 +13,7 @@ use Wikibase::Datatype::Value::Item;
 
 Readonly::Array our @EXPORT_OK => qw(obj2struct struct2obj);
 
-our $VERSION = 0.12;
+our $VERSION = 0.13;
 
 sub obj2struct {
 	my ($obj, $base_uri) = @_;
@@ -28,9 +28,14 @@ sub obj2struct {
 		err 'Base URI is required.';
 	}
 
-	my $struct_hr = {
-		'id' => $obj->id,
-	};
+	my $struct_hr = {};
+
+	if (defined $obj->id) {
+		$struct_hr->{'id'} = $obj->id;
+	} else {
+		# Key for information, that I am creating structure.
+		$struct_hr->{'add'} = '';
+	}
 
 	# Grammatical features.
 	foreach my $gf (@{$obj->grammatical_features}) {
@@ -346,12 +351,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2020-2023 Michal Josef Špaček
+© 2020-2024 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.12
+0.13
 
 =cut
